@@ -95,7 +95,7 @@ class Card(MuviBase):
         response = {
                 'id': card_token
             }
-        return self.ok(self.processor, response)
+        return self.ok(response)
 
     def get(self, customer_id: str, card_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
@@ -110,4 +110,4 @@ class Card(MuviBase):
     def list_all(self, customer_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
         cards = r.json()['tokens']
-        return self.ok([_format(card, customer_id) for card in cards], status=r.status_code)
+        return self.ok({'results': [_format(card, customer_id) for card in cards]}, status=r.status_code)
