@@ -1,5 +1,6 @@
 import mercadopago
 from iso8601 import parse_date
+from bson import ObjectId
 
 from ..MuviBase import MuviBase
 
@@ -30,14 +31,17 @@ def _format(response):
 
 
 class Payment(MuviBase):
-    def __init__(self, processor: str, sdk: mercadopago.SDK):
+    def __init__(self, processor: str, sdk: mercadopago.SDK, merchant_id: ObjectId):
         super().__init__(processor)
         self.sdk = sdk
+        self.merchant_id = merchant_id
 
     def create(self, payment_data: dict):
         payment_data = payment_data.copy()
+        merchant_id = str(self.merchant_id)
+        notification_url = f"https://apisportclub.xyz/notificacion/mp?source_news=webhooks&merchant={merchant_id}"
         payment_data_mp = {
-            "notification_url": None,
+            "notification_url": notification_url,
             "transaction_amount": round(payment_data['transaction_amount'], 2),
             "token": payment_data['token'],
             "installments": 1,
